@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm,v 1.114 2007/02/18 18:35:03 mbarbon Exp $
+## RCS-ID:      $Id: Wx.pm,v 1.116 2007/03/15 22:42:55 mbarbon Exp $
 ## Copyright:   (c) 2000-2006 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $XS_VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.68';
+$VERSION = '0.69';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -296,6 +296,11 @@ sub Wx::Log::SetTimestamp {
     Wx::Log::_SetTimestamp( $_[0], $ts_buf );
 }
 
+package Wx::PlThreadEvent;
+
+our %stash : shared;
+SetStash( \%stash );
+
 1;
 
 __END__
